@@ -29,7 +29,6 @@
 
 #include "portab.h"
 #include "system.h"
-#include "sdl_core.h"
 #include "ags.h"
 #include "nact.h"
 #include "input.h"
@@ -241,7 +240,7 @@ void smsg_out(int wNum, int wSize, int wColorR, int wColorG, int wColorB, int wF
 	sprite_t *sp;
 	int len = 0; // 処理した文字数?
 	bool needupdate = false;
-	MyRectangle uparea = {0,0,0,0};
+	SDL_Rect uparea = {0,0,0,0};
 	
 	// wRSize == 0 -> ルビ無し(SACT.MessageOutputからの呼出)
 
@@ -268,7 +267,7 @@ void smsg_out(int wNum, int wSize, int wColorR, int wColorG, int wColorB, int wF
 		char mbuf[20], rbuf[20];
 		int cw, delta, wcnt;
 		
-		wcnt = sdl_getTicks();
+		wcnt = sys_get_ticks();
 		
 		mbuf[0] = rbuf[0] = '\0';
 		msg = get_char(msg, mbuf, rbuf, sizeof(mbuf) -1); 
@@ -316,7 +315,7 @@ void smsg_out(int wNum, int wSize, int wColorR, int wColorG, int wColorB, int wF
 			needupdate = false;
 			
 			// keywait
-			delta = sdl_getTicks() - wcnt;
+			delta = sys_get_ticks() - wcnt;
 			if (delta < wSpeed) {
 				if (sys_keywait(wSpeed - delta, KEYWAIT_NONCANCELABLE)) {
 					
@@ -335,8 +334,8 @@ void smsg_out(int wNum, int wSize, int wColorR, int wColorG, int wColorB, int wF
 	
 	// Waitなしの出力は最後にupdate
 	if (needupdate) {
-		uparea.w = sp->cursize.width;
-		uparea.h = min(sp->cursize.height, uparea.y - sp->u.msg.dspcur.y + wLineSpace + wLineSpace + wRSize);
+		uparea.w = sp->width;
+		uparea.h = min(sp->height, uparea.y - sp->u.msg.dspcur.y + wLineSpace + wLineSpace + wRSize);
 		sp_updateme_part(sp, uparea.x, uparea.y, uparea.w, uparea.h);
 	}
 	
@@ -420,7 +419,7 @@ int smsg_keywait(int wNum1, int wNum2, int msglen) {
 	sact.waitkey = -1;
 	
 	while (sact.waitkey == -1 && !nact->is_quit) {
-		int st = sdl_getTicks();
+		int st = sys_get_ticks();
 		int interval = 25;
 		
 		// アニメパターンがある場合、その更新
@@ -434,7 +433,7 @@ int smsg_keywait(int wNum1, int wNum2, int msglen) {
 			update_mark(minfo[j].sp, minfo[j].cg);
 			i++;
 		} 
-		sys_keywait(interval - (sdl_getTicks() - st), KEYWAIT_NONCANCELABLE);
+		sys_keywait(interval - (sys_get_ticks() - st), KEYWAIT_NONCANCELABLE);
 	}
 	
 	sact.waittype = KEYWAIT_NONE;
@@ -447,13 +446,13 @@ int smsg_keywait(int wNum1, int wNum2, int msglen) {
   @param sp: 再描画するスプライト
  */
 void smsg_update(sprite_t *sp) {
-	SDL_Rect sp_rect = {0, 0, sp->cursize.width, sp->cursize.height};
+	SDL_Rect sp_rect = {0, 0, sp->width, sp->height};
 	int sx = 0;
 	int sy = 0;
 	int dx = sp->cur.x;
 	int dy = sp->cur.y;
-	int w = sp->cursize.width;
-	int h = sp->cursize.height;
+	int w = sp->width;
+	int h = sp->height;
 	if (!ags_clipCopyRect(&sp_rect, &sact.updaterect, &sx, &sy, &dx, &dy, &w, &h)) {
 		return;
 	}
@@ -547,10 +546,10 @@ static void set_align(char *msg, sprite_t *sp, int wSize, int wAlign) {
 		
 		switch (wAlign) {
 		case 1: // センタリング
-			adjx = (sp->cursize.width - mlen) / 2;
+			adjx = (sp->width - mlen) / 2;
 			break;
 		case 2: // 右寄せ
-			adjx = (sp->cursize.width - mlen);
+			adjx = (sp->width - mlen);
 			break;
 		}
 		sp->u.msg.dspcur.x = max(0, adjx);
